aboutsummaryrefslogtreecommitdiffstats
path: root/engine/items/tms.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/items/tms.asm')
-rw-r--r--engine/items/tms.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/items/tms.asm b/engine/items/tms.asm
index ea7fbcad..f3c6db98 100644
--- a/engine/items/tms.asm
+++ b/engine/items/tms.asm
@@ -1,6 +1,6 @@
; tests if mon [wcf91] can learn move [wMoveNum]
CanLearnTM:
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
ld [wd0b5], a
call GetMonHeader
ld hl, wMonHLearnset
@@ -1,6 +1,6 @@
-; tests if mon [wcf91] can learn move [wMoveNum]
+; tests if mon [wCurPartySpecies] can learn move [wMoveNum]
CanLearnTM: